//========================================================
// MPConvo Version 4
//
// Created by Cozmo, 2011
//
// Allows for easy placement and editing of multiplayer
// NPCs from within the SDK. Its primary purpose is to
// create entire missions using this functionality.
//========================================================
Class MPConvoPawn_V4 extends MPBot_Edit;

Var MPConvoV4_Storage MPCS;
//--------------------
// Interaction vars
//--------------------
struct INTERACTION
{
	var() int ConditionID; //0 (default) means don't check
	var() Name CheckNPCTag;
	var() string ConvoMessage[20];
	Var() int E_GiveMoneyToPlayer;
	var() int E_SetMissionCondition;
	Var() name E_TriggerTag;
	var() bool E_FollowPlayer;
	Var() String E_PathName;
	Var() String EP_Message;
	Var() int EP_GiveMoneyToPlayer;
	Var() int EP_SetMissionCondition;
	Var() String EP_ActionAtEndOfPath;
	Var() int D_SetMissionCondition;
	Var() string D_Message;
	Var() int D_GiveMoneyToPlayer;
	Var() name D_TriggerTag;
};

var() localized INTERACTION Interactions[10];
Var() int MissionNumber; //Simplified
Var() String IntroLine;
Var() string BusyMSG;
var() bool bDecorativePawn;
Var() string OneLine;
Var() class<Pawn> AppearAsClass;
Var() string PawnsName;

//--------------------
// NPC's convo vars
//--------------------
var DeusExPlayer TalkingTo;
var string TimerType; //"", "Talking", "Buying" and "Movement"
Var int OnMessage;
Var bool bFollowing;
var int storei;
var name oldorders;

//--------------------
// Respawn stuff
//--------------------
var() float TimeToRespawn;
var bool bRespawning;
var NPCRespawner2 Respawner;

//--------------------
// Movement stuff
//--------------------
var() String PatrolPathName;
var() bool bContinuePatrol;
Var() bool bShouldRunPath;
Var() bool bTeleportBack;
var() bool bShouldWait;
Var() float WaitTime;
Var() String FollowWaitMSG;
Var() String FollowAgainMSG;
var Int PathPoint;
var string ActivePath;
var MPConvoPath cpa;
var bool bRunningTo;
var DeusExPlayer FollowingPlayer;

//--------------------
function BeginPlay()
{
	local MPConvoV4_Storage MPS;
	local int i;
	local int n;

	if(AppearAsClass != None)
	{
		UnfamiliarName=PawnsName;
		FamiliarName=PawnsName;
		BindName=PawnsName;
		Mesh=AppearAsClass.default.Mesh;
		SetCollisionSize(AppearAsClass.default.CollisionRadius,AppearAsClass.default.CollisionHeight);
		BaseEyeHeight=AppearAsClass.default.BaseEyeHeight;
		AmbientSound=AppearAsClass.default.AmbientSound;
		SoundRadius=AppearAsClass.default.SoundRadius;
		SoundVolume=AppearAsClass.default.SoundVolume;
		bIsFemale=AppearAsClass.default.bIsFemale;
		MultiSkins[0]=AppearAsClass.default.MultiSkins[0];
		MultiSkins[1]=AppearAsClass.default.MultiSkins[1];
		MultiSkins[2]=AppearAsClass.default.MultiSkins[2];
		MultiSkins[3]=AppearAsClass.default.MultiSkins[3];
		MultiSkins[4]=AppearAsClass.default.MultiSkins[4];
		MultiSkins[5]=AppearAsClass.default.MultiSkins[5];
		MultiSkins[6]=AppearAsClass.default.MultiSkins[6];
		MultiSkins[7]=AppearAsClass.default.MultiSkins[7];
	}

	if (bIsFemale)
	{
		HitSound1 = Sound'FemalePainMedium';
		HitSound2 = Sound'FemalePainLarge';
		Die = Sound'FemaleDeath';
	}

	foreach AllActors(Class'MPConvoV4_Storage',MPS)
	{
		MPCS=MPS;
	}

	if(bRespawning == true)
	{
		if(Respawner == None)
		{
			Respawner = Spawn(Class'NPCRespawner2',,, location, rotation);
			Respawner.MPCPV4 = Self;
			Respawner.OOrders = Orders;
			Respawner.Ploc = Location;
			Respawner.Prot = Rotation;
			Respawner.Health2 = Health;
			Respawner.HealthHead2 = HealthHead;
			Respawner.HealthTorso2 = HealthHead;
			Respawner.HealthArmLeft2 = HealthArmLeft;
			Respawner.HealthArmRight2 = HealthArmRight;
			Respawner.HealthLegLeft2 = HealthLegLeft;
			Respawner.HealthLegRight2 = HealthLegRight;
		}
	}

	Super.BeginPlay();
}

function Frob(Actor Frobber, Inventory frobWith) 
{
	local DeusExPlayer Player;

	if(bDecorativePawn == False)
	{
		if(TalkingTo == None)
		{
			oldorders = Orders;
			//Orders = 'Standing';
			SetOrders('Standing');
			gotoState('Standing');
			broadcastmessage("DEBUG: orders are "$orders);
			TalkingTo = DeusExPlayer(Frobber);
			TalkingTo.ClientMessage(IntroLine);
			MPCInteract();
		}
		else
		{
			if(DeusExPlayer(Frobber)==TalkingTo)
			{
				if(TimerType != "") //More specific later maybe
				{
					MPCInteract();
				}
			}
			else
			{
				DeusExPlayer(Frobber).ClientMessage(BusyMSG);
			}
		}
	}
	else
	{
		DeusExPlayer(Frobber).ClientMessage(OneLine);
	}
}

function MPCInteract()
{
	local int i;
	local MPConvoPawn_V4 MPCP;

	if(TimerType == "Talking")
	{
	}
	else if(TimerType == "Following")
	{
		if(bShouldWait == False)
		{
			TalkingTo.ClientMessage(FollowWaitMSG);
			bShouldWait = True;
			SetTimer(WaitTime, false);
		}
		else
		{
			bShouldWait = False;
			TalkingTo.ClientMessage(FollowAgainMSG);
		}
	}
	else if(TimerType == "Path")
	{
	}
	else if(TimerType == "Buying")
	{
	}
	else //""
	{
		if(Interactions[MPCS.GetMissionCondition(TalkingTo, MissionNumber)].CheckNPCTag != '')
		{
			foreach AllActors(Class'MPConvoPawn_V4',MPCP)
			{
				if(MPCP.Tag == Interactions[MPCS.GetMissionCondition(TalkingTo, MissionNumber)].CheckNPCTag)
				{
					if(VSize(Location-TalkingTo.Location) > 400)
					{
						TimerType = "Talking";
						SetTimer(2.5, true);
						OnMessage = 0; //Just in case
						storei = i;
					}
				}
			}
		}
		else
		{
			TimerType = "Talking";
			SetTimer(2.25, true);
			OnMessage = 0; //Just in case
			storei = i;
		}
	}
}

function Timer()
{
	local string ConvoText;
	local Actor A;

	//broadcastmessage("DEBUG: timertype is "$timertype);
	//broadcastmessage("DEBUG: orders are "$orders);

	if(TimerType == "Talking")
	{
		if(TalkingTo != None)
		{
			if(VSize(Location-TalkingTo.Location) > 300) //if they wander off, end the conversation.
			{
				OnMessage = 0;
				TalkingTo = None;
				TimerType = "";
				SetOrders(oldorders);
				gotoState(oldorders);
			}
			else
			{
				ConvoText = Interactions[MPCS.GetMissionCondition(TalkingTo, MissionNumber)].ConvoMessage[OnMessage];

				if(ConvoText != "")
				{
					TalkingTo.ClientMessage(ConvoText);
					OnMessage++;
				}
				else
				{
					//END CONVO STUFF HERE
					//TalkingTo.ClientMessage("DEBUG: endconvo");

					if(Interactions[MPCS.GetMissionCondition(TalkingTo, MissionNumber)].E_GiveMoneyToPlayer > 0)
					{
						TalkingTo.Credits+=Interactions[MPCS.GetMissionCondition(TalkingTo, MissionNumber)].E_GiveMoneyToPlayer;
						TalkingTo.ClientMessage("|p7You received "$Interactions[MPCS.GetMissionCondition(TalkingTo, MissionNumber)].E_GiveMoneyToPlayer$" credits.");
					}

					if(Interactions[MPCS.GetMissionCondition(TalkingTo, MissionNumber)].E_SetMissionCondition != 1337) //literal hax
					{
						MPCS.SetCondition(talkingto, MissionNumber, Interactions[MPCS.GetMissionCondition(TalkingTo, MissionNumber)].E_SetMissionCondition);
					}

					if(Interactions[MPCS.GetMissionCondition(TalkingTo, MissionNumber)].E_TriggerTag != '')
					{
						foreach AllActors(class 'Actor', A, Interactions[MPCS.GetMissionCondition(talkingto, MissionNumber)].E_TriggerTag)
						{
							A.Trigger(Self, talkingto);
						}
					}

					if(Interactions[MPCS.GetMissionCondition(TalkingTo, MissionNumber)].E_PathName != "")
					{
						TimerType = "Path";
						OnMessage = 0;
						PathPoint = 0; //reset, just in case
						ActivePath = Interactions[MPCS.GetMissionCondition(TalkingTo, MissionNumber)].E_PathName;
						GetMoving();
						SetTimer(0.0, false);
						return;
					}
					
					if(Interactions[MPCS.GetMissionCondition(TalkingTo, MissionNumber)].E_FollowPlayer == True)
					{
						FollowingPlayer = TalkingTo;
						TimerType = "Following";
						OnMessage = 0;
						GetFollowing();
						SetTimer(0.0, false);
						return;
					}

					OnMessage = 0;
					TalkingTo = None;
					TimerType = "";
					SetOrders(oldorders);
					gotoState(oldorders);
				}
			}
		}
		else
		{
			OnMessage = 0;
			TimerType = "";
		}
	}
	else if(TimerType == "Following")
	{
		FollowingPlayer.ClientMessage("|p2You have left your follower.");

		FollowingPlayer = None;
		TalkingTo = None;
		
		if(bTeleportBack == True)
		{
			Respawner.SetTimer(1.0, false); //ehehehe
		}
	}
}

function Touch( actor Other )
{
	local MPConvoPath cpt;

	Super.Touch(Other);

	if(other.IsA('MPConvoPath'))
	{
		cpt = MPConvopath(Other);

		if(ActivePath == "") //var is for special E_ paths only
		{
			if((PatrolPathName == cpt.Pathname) && (PathPoint == cpt.PathPoint))
			{
				if(cpt.bEndPoint == True)
				{
					if(bContinuePatrol == True)
					{
						PathPoint = 0;
						GetMoving();
					}
					else
					{
						PathPoint = 0;
						SetOrders('Standing');
						gotoState('Standing');
					}
				}
				else
				{
					PathPoint += 1;
					GetMoving();
				}
			}
		}
		else
		{
			if((ActivePath == cpt.Pathname) && (PathPoint == cpt.PathPoint))
			{
				if(cpt.bEndPoint == True)
				{
					if(Interactions[MPCS.GetMissionCondition(TalkingTo, MissionNumber)].EP_SetMissionCondition != 1337)
					{
						MPCS.SetCondition(talkingto, MissionNumber, Interactions[MPCS.GetMissionCondition(TalkingTo, MissionNumber)].EP_SetMissionCondition);
					}

					if(Interactions[MPCS.GetMissionCondition(TalkingTo, MissionNumber)].EP_Message != "")
					{
						TalkingTo.ClientMessage(Interactions[MPCS.GetMissionCondition(TalkingTo, MissionNumber)].EP_Message);
					}

					if(Interactions[MPCS.GetMissionCondition(TalkingTo, MissionNumber)].EP_GiveMoneyToPlayer > 0)
					{
						TalkingTo.Credits+=Interactions[MPCS.GetMissionCondition(TalkingTo, MissionNumber)].EP_GiveMoneyToPlayer;
						TalkingTo.ClientMessage("|p7You received "$Interactions[MPCS.GetMissionCondition(TalkingTo, MissionNumber)].EP_GiveMoneyToPlayer$" credits.");
					}

					if(Interactions[MPCS.GetMissionCondition(TalkingTo, MissionNumber)].EP_ActionAtEndOfPath == "Stand")
					{
						Acceleration=vect(0,0,0);
						PathPoint = 0;
						SetOrders('Standing');
						gotoState('Standing');
					}
					else if(Interactions[MPCS.GetMissionCondition(TalkingTo, MissionNumber)].EP_ActionAtEndOfPath == "Berserk")
					{
						ChangeAlly('AggPlayer', -1.000000, True);
						ChangeAlly('Player', -1.000000, True);
						ChangeAlly('Cop', -1.000000, True);
						ChangeAlly('Rarrow', -1.000000, True);
						ChangeAlly('LumPath', -1.000000, True);
						ChangeAlly('Criminal', -1.000000, True);
					}
					else if(Interactions[MPCS.GetMissionCondition(TalkingTo, MissionNumber)].EP_ActionAtEndOfPath == "AttackPlayer")
					{
						ChangeAlly('Player', -1.000000, True);
					}
					else if(Interactions[MPCS.GetMissionCondition(TalkingTo, MissionNumber)].EP_ActionAtEndOfPath == "Patrol")
					{
						PathPoint = 0;
						GetMoving();
					}
					else if(Interactions[MPCS.GetMissionCondition(TalkingTo, MissionNumber)].EP_ActionAtEndOfPath == "Die")
					{
						Acceleration=vect(0,0,0);
						SetTimer(0.0, false);
						PlayAnimPivot('DeathFront',, 0.1);
						PlayDyingSound();
						GoToState('FakeDeathState');
					}
					else if(Interactions[MPCS.GetMissionCondition(TalkingTo, MissionNumber)].EP_ActionAtEndOfPath == "Vanish")
					{
						Acceleration=vect(0,0,0);
						SetTimer(0.0, false);
						GoToState('FakeDeathState');
					}
				}
				else
				{
					PathPoint += 1;
					GetMoving();
				}
			}
		}
	}
}

function GetMoving()
{
	local MPConvoPath cpa2;

	foreach AllActors(class'MPConvoPath',cpa2)
	{
		if(PatrolPathName == cpa2.PathName)
		{
			if(PathPoint == cpa2.PathPoint)
			{
				cpa = cpa2;
				SetOrders('Patrolling');
				gotoState('Patrolling');
			}
		}
	}
}

function GetFollowing()
{
	local vector loc;

	if((FollowingPlayer != None) && (bShouldWait == False))
	{
		if(VSize(Location-FollowingPlayer.Location) > 1200)
		{
			loc = FollowingPlayer.Location;
			loc -= 32.0 * FollowingPlayer.CollisionRadius * vector(FollowingPlayer.ViewRotation);
			loc.Z += FollowingPlayer.CollisionHeight * 0.9;

			SetLocation(loc);
		}
		else if(VSize(Location-FollowingPlayer.Location) > 300)
		{
			bRunningTo = True;
			SetOrders('Following');
			gotoState('Follow');
		}
		else if(VSize(Location-FollowingPlayer.Location) > 200)
		{
			bRunningTo = False;
			SetOrders('Following');
			gotoState('Follow');
		}
		else
		{
			SetOrders('Standing');
			gotoState('Standing');
		}
	}
}

function Tick(float deltaTime)
{
	// Keep turning towards the person we're speaking to
	if (TalkingTo != None)
	{
		LookAtActor(TalkingTo, true, true, true, 0, 0.5);
		LipSynch(deltaTime); //gesture randomly
	}

	Super.Tick(deltatime);
}

function Carcass SpawnCarcass()
{
	if(Respawner != None)
	{
		Respawner.SetTimer(TimeToRespawn, False);
	}
}

function FakeDeath(pawn Killer, name damageType, vector HitLocation)
{
	local DeusExPlayer DXP;
	local actor a;

	OnMessage = 0;
	TalkingTo = None;
	TimerType = "";

	if(Killer.IsA('DeusExPlayer'))
	{
		DXP = DeusExPlayer(Killer);

		//broadcastmessage("DEBUG: fakedeath");

		//TimerType = "Dying";
		//SetTimer(2.0, true);

		if(Interactions[MPCS.GetMissionCondition(DXP, MissionNumber)].D_Message != "")
		{
			DXP.ClientMessage(Interactions[MPCS.GetMissionCondition(DXP, MissionNumber)].D_Message);
		}
	
		if(Interactions[MPCS.GetMissionCondition(DXP, MissionNumber)].D_GiveMoneyToPlayer > 0)
		{
			DXP.Credits+=Interactions[MPCS.GetMissionCondition(DXP, MissionNumber)].D_GiveMoneyToPlayer;
			DXP.ClientMessage("|p7You received "$Interactions[MPCS.GetMissionCondition(DXP, MissionNumber)].D_GiveMoneyToPlayer$" credits.");
		}

		if(Interactions[MPCS.GetMissionCondition(DXP, MissionNumber)].D_SetMissionCondition != 1337) //literal hax
		{
			MPCS.SetCondition(DXP, MissionNumber, Interactions[MPCS.GetMissionCondition(DXP, MissionNumber)].D_SetMissionCondition);
		}

		if(Interactions[MPCS.GetMissionCondition(DXP, MissionNumber)].D_TriggerTag != '')
		{
			foreach AllActors(class 'Actor', A, Interactions[MPCS.GetMissionCondition(DXP, MissionNumber)].D_TriggerTag)
			{
				A.Trigger(Self, DXP);
			}
		}
	}

	FollowingPlayer=None;
	PathPoint=0;
	Acceleration=vect(0,0,0);
	SetTimer(0.0, false);
	PlayDying(damageType, hitLocation);
	GoToState('FakeDeathState');
}

function PlayDying(name damageType, vector hitLoc) //taken from ScriptedPawn because I might want to edit this
{
	local Vector X, Y, Z;
	local float dotp;

	if (Region.Zone.bWaterZone)
		PlayAnimPivot('WaterDeath',, 0.1);
	else if (bSitting)  // if sitting, always fall forward
		PlayAnimPivot('DeathFront',, 0.1);
	else
	{
		GetAxes(Rotation, X, Y, Z);
		dotp = (Location - HitLoc) dot X;

		// die from the correct side
		if (dotp < 0.0)		// shot from the front, fall back
			PlayAnimPivot('DeathBack',, 0.1);
		else				// shot from the back, fall front
			PlayAnimPivot('DeathFront',, 0.1);
	}

	// don't scream if we are stunned
	if ((damageType == 'Stunned') || (damageType == 'KnockedOut') ||
	    (damageType == 'Poison') || (damageType == 'PoisonEffect'))
	{
		bStunned = True;
		if (bIsFemale)
			PlaySound(Sound'FemaleUnconscious', SLOT_Pain,,,, RandomPitch());
		else
			PlaySound(Sound'MaleUnconscious', SLOT_Pain,,,, RandomPitch());
	}
	else
	{
		bStunned = False;
		PlayDyingSound();
	}
}

State FakeDeathState
{
	ignores EnemyNotVisible;

	function FakeDeath(pawn Killer, name damageType, vector HitLocation)
	{
	}

	function SetFall()
	{
		StartFalling('Standing', 'ContinueStand');
	}

	function AnimEnd()
	{
		PlayWaiting();
	}

	function HitWall(vector HitNormal, actor Wall)
	{
	}

	function Tick(float deltaSeconds)
	{
		//animTimer[1] += deltaSeconds;
		//Global.Tick(deltaSeconds);
	}

	function BeginState()
	{
		StandUp();
		SetEnemy(None, EnemyLastSeen, true);
		Disable('AnimEnd');
		bCanJump = false;

		bStasis = False;

		SetupWeapon(false);
		SetDistress(false);
		SeekPawn = None;
		EnableCheckDestLoc(false);
	}

	function EndState()
	{
		//bStasis = True;

		StopBlendAnims();
	}

Begin:
	Sleep(1.8);
	Style=STY_Translucent;
	Sleep(0.6);
	DrawType=DT_None;
	Style=STY_Normal;
	Respawner.SetTimer(TimeToRespawn, false);
	SetCollision(False);
	WaitForLanding();
	if (!bUseHome)
		Goto('StartStand');

MoveToBase:


StartStand:
	Acceleration=vect(0,0,0);
	Goto('Stand');

ContinueFromDoor:
	//Goto('MoveToBase');

Stand:

ContinueStand:
	// nil
	//bStasis = True;

	PlayWaiting();
	//if (!bPlayIdle)
	//	Goto('DoNothing');
	//Sleep(FRand()*14+8);

//Begin:
}

State Patrolling
{
	function SetFall()
	{
		StartFalling('Patrolling', 'ContinuePatrol');
	}

	function HitWall(vector HitNormal, actor Wall)
	{
		if (Physics == PHYS_Falling)
			return;
		Global.HitWall(HitNormal, Wall);
		CheckOpenDoor(HitNormal, Wall);
	}
	
	function AnimEnd()
	{
		PlayWaiting();
	}

	function EndState()
	{
		Enable('AnimEnd');
	}

	Begin:

	if(cpa != none)
	{
		if(bShouldRunPath == True)
		{
			PlayRunning();
			MoveToward(cpa, 180.000000);
		}
		else
		{
			PlayWalking();
			MoveToward(cpa, 0.120000);
		}
	}
}

State Follow
{
	function SetFall()
	{
		StartFalling('Patrolling', 'ContinuePatrol');
	}

	function HitWall(vector HitNormal, actor Wall)
	{
		if (Physics == PHYS_Falling)
			return;
		Global.HitWall(HitNormal, Wall);
		CheckOpenDoor(HitNormal, Wall);
	}
	
	function AnimEnd()
	{
		PlayWaiting();
	}

	function BeginState()
	{
		Disable('AnimEnd');
		SeekPawn = None;
	}

	function EndState()
	{
		//EnableCheckDestLoc(false);
		Enable('AnimEnd');
		//bStasis = true;
	}

Begin:

	if(FollowingPlayer != none)
	{
		if(bRunningTo == False)
		{
			PlayWalking();
			MoveToward(FollowingPlayer, 0.120000);
		}
		else
		{
			PlayRunning();
			MoveToward(FollowingPlayer, 200.000000);
		}

		Sleep(1.0);
		GetFollowing();
	}
	else
	{
		//Stuff here for waiting maybe
		SetOrders(oldorders);
		gotoState(oldorders);
	}
}

defaultproperties
{
     Interactions(0)=(ConditionID=1337,E_SetMissionCondition=1337,D_SetMissionCondition=1337,EP_SetMissionCondition) //I'm so sorry
     Interactions(1)=(ConditionID=1337,E_SetMissionCondition=1337,D_SetMissionCondition=1337,EP_SetMissionCondition) 
     Interactions(2)=(ConditionID=1337,E_SetMissionCondition=1337,D_SetMissionCondition=1337,EP_SetMissionCondition)
     Interactions(3)=(ConditionID=1337,E_SetMissionCondition=1337,D_SetMissionCondition=1337,EP_SetMissionCondition)
     Interactions(4)=(ConditionID=1337,E_SetMissionCondition=1337,D_SetMissionCondition=1337,EP_SetMissionCondition)
     Interactions(5)=(ConditionID=1337,E_SetMissionCondition=1337,D_SetMissionCondition=1337,EP_SetMissionCondition)
     Interactions(6)=(ConditionID=1337,E_SetMissionCondition=1337,D_SetMissionCondition=1337,EP_SetMissionCondition)
     Interactions(7)=(ConditionID=1337,E_SetMissionCondition=1337,D_SetMissionCondition=1337,EP_SetMissionCondition)
     Interactions(8)=(ConditionID=1337,E_SetMissionCondition=1337,D_SetMissionCondition=1337,EP_SetMissionCondition)
     Interactions(9)=(ConditionID=1337,E_SetMissionCondition=1337,D_SetMissionCondition=1337,EP_SetMissionCondition)
     GroundSpeed=0.120000
     DrawType=DT_Mesh
     bTeleportBack=False
     Mesh=LodMesh'DeusExCharacters.GM_DressShirt'
     MultiSKins(0)=Texture'CoreTexPaper.Paper.ClenWhitPaint_A'
     MultiSKins(1)=Texture'CoreTexPaper.Paper.ClenWhitPaint_A'
     //MultiSKins(2)=Texture'CoreTexPaper.Paper.ClenWhitPaint_A'
     MultiSKins(3)=Texture'CoreTexPaper.Paper.ClenWhitPaint_A'
     MultiSKins(4)=Texture'CoreTexPaper.Paper.ClenWhitPaint_A'
     MultiSKins(5)=Texture'CoreTexPaper.Paper.ClenWhitPaint_A'
     MultiSKins(6)=Texture'DeusExCharacters.Skins.FramesTex2'
     MultiSKins(7)=Texture'DeusExCharacters.Skins.FramesTex2'
     WaitTime=90.000000
     PawnsName="NPC"
     BusyMSG="|p3NPC: Hold on. I'm talking to someone at the moment."
     bRespawning=True
     TimeToRespawn=10.000000
     bContinuePatrol=True
     FollowWaitMSG="|p3NPC: Okay - I'll wait here for a while."
     FollowAgainMSG="|p3NPC: All right, I'm coming."
}