//=============================================================================
// Var Storage
//
// Keeps track of conditions / "flags" for missions or objectives.
//
// Example mission: Kill a mechanic for a Man In Black (MIB).
//
// Condition is an array with 60 "slots" for integers. We're going to use these
// as storage for information. Let's pretend Condition[0] and Condition [1] are
// already being used by other missions.
//
// So we use Condition[2] for this mission. The player speaks to the mib, and
// has the default Condition[2] = 0. So we start the mission and after the
// conversation we set it to 1.
//
// The player shoots and kills the mechanic. If Condition[2] is 1, then the
// player is on this mission, and we should change it to 2, meaning he's dead.
//
// The MIB checks Condition[2] again when you talk to him, and now that it's 2
// he will give you a reward. We can then set this to 0 so you can do the
// mission again, or a new number (in this case, 3) that means you've completed
// the mission and will get different dialogue from the MIB.
//=============================================================================
class MPConvoV4_Storage extends Mutator config(DeusEx);

//Var DeusExPlayer DXP[40];
//Var int Condition[40];

struct Storagez
{
	Var DeusExPlayer DXP;
	var int Condition[40];
};
var() localized Storagez StoredVars[40];

function int GetMissionCondition(DeusExPlayer DEP, int MissionNumbah)
{
	//local int ConditionInt;
	local int i;

	for (i=1; i<40; i++)
	{
		if(StoredVars[i].DXP == DEP)
		{
			return StoredVars[i].Condition[MissionNumbah];
		}
	}
}

function SetCondition(DeusExPlayer DEP, int MissionNumbah, int ChangeTo)
{
	local int i;

	for (i=1; i<40; i++)
	{
		if(StoredVars[i].DXP == DEP)
		{
			StoredVars[i].Condition[MissionNumbah] = ChangeTo;
		}
	}
}

function PostBeginPlay()
{
	Level.Game.BaseMutator.AddMutator(Self);

	Log("=============================================");
	Log("MPConvo_V4 mod by Cozmo. Successfully loaded.");
	Log("=============================================");

	SetTimer(1.5, true); //Potentially 1600 things happen when this is triggered. Worried about performance...
}

function ModifyPlayer(Pawn Other)
{
	local Human P;
	local int i;
	local int x;
	local int q;

	if(Other.IsA('Human'))
	{
		P = Human(Other);
	}
	else
	{
		return;
	}

	for (i=1; i<40; i++)
	{
		if(StoredVars[i].DXP == p)
		{
			return;
		}
	}

	for (x=1; x<40; x++)
	{
		if(StoredVars[x].DXP == None)
		{
			StoredVars[x].DXP = P;

			for(q=1; q<40; q++) //New player in the slot. Reset all conditions...
			{
				StoredVars[x].Condition[q] = 0;
			}

			return;
		}
	}
}

defaultproperties
{
}
